"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findAddressLookupTablePda = exports.getAddressLookupTableSize = exports.getAddressLookupTableGpaBuilder = exports.safeFetchAllAddressLookupTable = exports.fetchAllAddressLookupTable = exports.safeFetchAddressLookupTable = exports.fetchAddressLookupTable = exports.deserializeAddressLookupTable = exports.getAddressLookupTableAccountDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getAddressLookupTableAccountDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u32()],
        ['deactivationSlot', s.u64()],
        ['lastExtendedSlot', s.u64()],
        ['lastExtendedStartIndex', s.u8()],
        ['authority', s.option(s.publicKey(), { fixed: true })],
        ['padding', s.u16()],
        ['addresses', s.array(s.publicKey(), { size: 'remainder' })],
    ], { description: 'AddressLookupTable' }), (value) => ({
        ...value,
        discriminator: 1,
        padding: 0,
    }));
}
exports.getAddressLookupTableAccountDataSerializer = getAddressLookupTableAccountDataSerializer;
function deserializeAddressLookupTable(context, rawAccount) {
    return (0, umi_1.deserializeAccount)(rawAccount, getAddressLookupTableAccountDataSerializer(context));
}
exports.deserializeAddressLookupTable = deserializeAddressLookupTable;
async function fetchAddressLookupTable(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_1.assertAccountExists)(maybeAccount, 'AddressLookupTable');
    return deserializeAddressLookupTable(context, maybeAccount);
}
exports.fetchAddressLookupTable = fetchAddressLookupTable;
async function safeFetchAddressLookupTable(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists
        ? deserializeAddressLookupTable(context, maybeAccount)
        : null;
}
exports.safeFetchAddressLookupTable = safeFetchAddressLookupTable;
async function fetchAllAddressLookupTable(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_1.assertAccountExists)(maybeAccount, 'AddressLookupTable');
        return deserializeAddressLookupTable(context, maybeAccount);
    });
}
exports.fetchAllAddressLookupTable = fetchAllAddressLookupTable;
async function safeFetchAllAddressLookupTable(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeAddressLookupTable(context, maybeAccount));
}
exports.safeFetchAllAddressLookupTable = safeFetchAllAddressLookupTable;
function getAddressLookupTableGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.get('splAddressLookupTable').publicKey;
    return (0, umi_1.gpaBuilder)(context, programId)
        .registerFields([
        ['discriminator', s.u32()],
        ['deactivationSlot', s.u64()],
        ['lastExtendedSlot', s.u64()],
        ['lastExtendedStartIndex', s.u8()],
        ['authority', s.option(s.publicKey(), { fixed: true })],
        ['padding', s.u16()],
        ['addresses', s.array(s.publicKey(), { size: 'remainder' })],
    ])
        .deserializeUsing((account) => deserializeAddressLookupTable(context, account))
        .whereField('discriminator', 1);
}
exports.getAddressLookupTableGpaBuilder = getAddressLookupTableGpaBuilder;
function getAddressLookupTableSize(context) {
    return getAddressLookupTableAccountDataSerializer(context).fixedSize;
}
exports.getAddressLookupTableSize = getAddressLookupTableSize;
function findAddressLookupTablePda(context, seeds) {
    const s = context.serializer;
    const programId = context.programs.get('splAddressLookupTable').publicKey;
    return context.eddsa.findPda(programId, [
        s.publicKey().serialize(seeds.authority),
        s.u64().serialize(seeds.recentSlot),
    ]);
}
exports.findAddressLookupTablePda = findAddressLookupTablePda;
//# sourceMappingURL=addressLookupTable.js.map